<?php
/*
** Zabbix
** Copyright (C) 2001-2015 Zabbix SIA
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

define('CONF_DIR','/etc/sysconfig/network-scripts');
define('NETWORK_CONF_FILE','/tmp/elisa-network-conf.tmp');




require_once dirname(__FILE__).'/include/config.inc.php';
require_once dirname(__FILE__).'/include/js.inc.php';
require_once dirname(__FILE__).'/include/users.inc.php';
require_once dirname(__FILE__).'/include/forms.inc.php';

$config = select_config();
$userdata = getUserFormData(CWebUser::$data['userid'], $config, true);




$page['title'] = _('Network configuration');
$page['file'] = 'elisa_network.php';
$page['hist_arg'] = array();
$page['scripts'] = ['elisa.network.js'];

require_once dirname(__FILE__).'/include/page_header.php';

$themes = array_keys(Z::getThemes());
$themes[] = THEME_DEFAULT;

// VAR	TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
$fields = array(
	// actions
	'if'=>						array(T_ZBX_STR, O_OPT, P_SYS,			null,	null),
	'route'=>					array(T_ZBX_STR, O_OPT, P_SYS,			null,	null),
	'bond'=>					array(T_ZBX_STR, O_OPT, P_SYS,			null,	null),
	'hostname'=>				array(T_ZBX_STR, O_OPT, P_SYS,			null,	null),
	'updateNetwork'=>			array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
	'updateRoute'=>				array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
	'updateHostname'=>			array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
	'removeBonding'=>			array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
	'createBonding'=>			array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
	'updateBonding'=>			array(T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null),
	'createBondingForm'=>		array(T_ZBX_STR, O_OPT, P_SYS,	null,	null),
	'form_refresh' =>			array(T_ZBX_INT, O_OPT,	null,	null,	null)
);
check_fields($fields);


$data = array();
$data['redirect'] = '';
/*
 * Actions
 */


$createBondingError = false;


if (hasRequest('updateNetwork') && hasRequest('if')) {
	$configItems = getRequest('if', array());
	$fileContent = '';
	$prevname = 'init';
	$name = '';
	$enabled = 'no';
	$ip = '';
	$mask = '';
	$gateway = '';
	$g_ip = '';
	$g_mask = '';
	$g_gateway = '';
	$error = '';
	$ipregex = "/^((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?))$/" ;
	foreach ($configItems as $key => $value) {
		if($value['enabled']==1){ $enabled='yes';}else{$enabled='no';}
		$ip=$value['ip']; if($enabled == 'no'){$ip='';}; if (($ip !='' && ! preg_match($ipregex, $ip) && $error == '' ) || ($ip =='' && $enabled=='yes')) { $error = "'".$ip."' " . _('is not valid IP') ; } 
		$mask=$value['mask']; if($enabled == 'no'){$mask='';}; if ($mask !='' && ! preg_match($ipregex, $mask) && $error == '' ) { $error = "'".$mask."' " . _('is not valid netmask') ; }
		$gateway=$value['gateway']; if($enabled == 'no'){$gateway='';}; if ($gateway !='' && ! preg_match($ipregex, $gateway) && $error == '' ) { $error = _('Gateway') . " '".$gateway."' " . _('is not valid IP') ; }
		if($gateway!=""){ $g_ip = $ip; $g_gateway = $gateway; $g_mask = $mask; }
		$fileContent .= "$key|$enabled|$ip|$mask|$gateway\n"; 
		$gateway=''; $enabled = 'no'; $ip = ''; $mask = '';

		//add_audit_details(AUDIT_ACTION_UPDATE, 99, 0, $key."=".$value, 'settings');
	}	
	

	if($g_ip == ''){ $error = _('IP address for primary interface is not set'); }
	else if($g_gateway == ''){ $error = _('Default gateway for primary interface is not set'); }
	
	if($error == ''){
		$result = file_put_contents(NETWORK_CONF_FILE,$fileContent);
		exec('(sudo /usr/share/elisa/bin/elisa-setNetwork.sh "'.NETWORK_CONF_FILE.'") 2>/dev/null 1>/dev/null &', $outputUpdate, $rci);
		$result = false;
		if($rci==0){$result=true; $data['redirect'] = $g_ip; }else{$data['redirect'] = '';}
		show_messages($result, _('Network Configuration changed. You will be redirect to the new IP in 60 seconds.'), _('Network Configuration update failed'));
		sleep(1);
	}else{
		show_messages(false, '', $error);
	}
	
}else if (hasRequest('updateRoute')) {
	$configItems = getRequest('route', array());
	$fileContent = '';
	$prevuuid = 'init';
	$destination = '';
	$mask = '';
	$gateway = '';
	$if = '';
	$error = '';
	$ipregex = "/^((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?))$/" ;
	foreach ($configItems as $key => $value) {
		$destination=$value['destination']; if(($destination !='' && ! preg_match($ipregex, $destination)) || ($destination == '')  && $error == '' ) { $error = "'".$destination."' " . _('is not valid IP') ; }
		$mask=$value['mask']; if(($mask !='' && ! preg_match($ipregex, $mask) )  && $error == '' ) { $error = "'".$mask."' " . _('is not valid netmask') ; }
		$gateway=$value['gateway']; if(($gateway !='' && ! preg_match($ipregex, $gateway)) || ($gateway == '')  && $error == '' ) { $error = "'".$gateway."' " . _('is not valid IP') ; } 
		$if=$value['if'];
		
		//print "$if|$destination|$mask|$gateway<br>";
		$fileContent .= "$if|$destination|$mask|$gateway\n"; 
		$destination = ''; $mask = ''; $gateway = ''; $if = '';
		
		//add_audit_details(AUDIT_ACTION_UPDATE, 99, 0, $key."=".$value, 'settings');
	}	
	
	if($error == ''){
		$result = file_put_contents(NETWORK_CONF_FILE,$fileContent);
		//exec('(sudo /usr/share/elisa/bin/elisa-setNetworkRoute.sh "'.NETWORK_CONF_FILE.'") 2>/dev/null 1>/dev/null &', $outputUpdate, $rci);
		exec('sudo /usr/share/elisa/bin/elisa-setNetworkRoute.sh "'.NETWORK_CONF_FILE.'"', $outputRouteUpdate, $rci);
		//var_dump($outputRouteUpdate);
		$result = false;
		if($rci==0){ $result=true; }
		show_messages($result, _('Network Configuration changed'), _('Network Configuration update failed'));
		sleep(1);
	}else{
		show_messages(false, '', $error);
	}


}else if (hasRequest('removeBonding')) {
	$bondname = getRequest('bond', '');
	exec('netstat -i | grep -e "^'.$bondname.' "', $outputBondCheck, $rc1);
	if(count($outputBondCheck) == 1){
		exec('sudo /usr/share/elisa/bin/elisa-setNetworkBondRemove.sh "'.$bondname.'"', $outputBondRemove, $rci);
		//var_dump($outputBondRemove);
		$result = false;
		if($rci==0){ $result=true; }
		show_messages($result, _('Network Configuration changed'), _('Network Configuration update failed'));
		sleep(1);
	}else{
		show_messages(false, '', _('Bonding was not found'));
	}
}else if (hasRequest('createBonding') || hasRequest('updateBonding')) {
	$bondname = getRequest('bond', '');
	$ifItems = getRequest('if', array());
	exec('netstat -i | grep -e "^'.$bondname.' "', $outputBondCheck, $rc1);
	if($bondname == ''){
		$createBondingError = true;
		show_messages(false, '', _('Bonding name is not set'));
	}else if(count($outputBondCheck) != 0){		
		$createBondingError = true;
		show_messages(false, '', _('Bonding name is already used'));
	}else if(count($ifItems) < 2){	
		$createBondingError = true;
		show_messages(false, '', _('At least 2 interfaces must be selected'));
	}else{
		$ifNames = '';
		$i = 0;
		foreach($ifItems as $if){
			if($i>0){$ifNames .= " ";}
			$ifNames .= $if;
			$i++;
		}
		exec('sudo /usr/share/elisa/bin/elisa-setNetworkBondCreate.sh "'.$bondname.'" "'.$ifNames.'"', $outputBondCreate, $rci);
		//var_dump($outputBondCreate);
		$result = false;
		if($rci==0){ $result=true; }
		show_messages($result, _('Network Configuration changed'), _('Network Configuration update failed'));
		sleep(1);
	}
}else if (hasRequest('updateHostname') || hasRequest('hostname')) {
	$hostname = getRequest('hostname', '');
	if($hostname == ''){
		show_messages(false, '', _('Hostname is not set'));
	}else{
		exec('(sudo /usr/share/elisa/bin/elisa-setNetworkHostname.sh "'.$hostname.'") 2>/dev/null 1>/dev/null &', $outputUpdateHostname, $rci);
		$result = false;
		if($rci==0){$result=true; $data['redirect'] = $_SERVER["HTTP_HOST"]; }else{$data['redirect'] = '';}
		show_messages($result, _('Hostname changed. Certificates update is in the process. You will be redirect to login page in 60 seconds.'), _('Network Configuration update failed'));
		sleep(1);
	}
}


/*
 * Display
 */
 


$data['interfaces'] = [];
$ifs = exec('netstat -i | grep -v -e "^lo" | tail -n +3 | cut -d" " -f1', $output, $rc1);
foreach($output as $line){
	$data['ifs'][$line]['name'] = $line; 
	$data['ifs'][$line]['enabled'] = false; 
	$data['ifs'][$line]['ip'] = ''; 
	$data['ifs'][$line]['mask'] = ''; 
	$data['ifs'][$line]['gateway'] = ''; 
	$data['ifs'][$line]['slave'] = false; 
	$data['ifs'][$line]['bond'] = false; 
	$data['ifs'][$line]['master'] = ''; 
	if(file_exists(CONF_DIR."/ifcfg-".$line)){
		$fn = fopen(CONF_DIR."/ifcfg-".$line,"r");
		while(! feof($fn))  {
			$cfg = fgets($fn);
			if (strpos($cfg, 'IPADDR') !== false) { $data['ifs'][$line]['ip'] = trim(trim(substr($cfg, strpos($cfg, "=") + 1)),'"'); }
			if (strpos($cfg, 'NETMASK') !== false) { $data['ifs'][$line]['mask'] = trim(trim(substr($cfg, strpos($cfg, "=") + 1)),'"'); }
			if (strpos($cfg, 'GATEWAY') !== false) { $data['ifs'][$line]['gateway'] = trim(trim(substr($cfg, strpos($cfg, "=") + 1)),'"'); }
			if (strpos($cfg, 'ONBOOT') !== false) { $onboot = trim(trim(substr($cfg, strpos($cfg, "=") + 1)),'"'); if($onboot == "yes"){ $data['ifs'][$line]['enabled'] = true; } }
			if (strpos($cfg, 'SLAVE') !== false) { $slave = trim(trim(substr($cfg, strpos($cfg, "=") + 1)),'"'); if($slave == "yes"){ $data['ifs'][$line]['slave'] = true; } }
			if (strpos($cfg, 'BONDING_MASTER') !== false) { $bond = trim(trim(substr($cfg, strpos($cfg, "=") + 1)),'"'); if($bond == "yes"){ $data['ifs'][$line]['bond'] = true; } }
			if (strpos($cfg, 'MASTER') !== false) { $data['ifs'][$line]['master'] = trim(trim(substr($cfg, strpos($cfg, "=") + 1)),'"'); }
		}
		fclose($fn);
	}
	if(! in_array($line,$data['interfaces']) && ! $data['ifs'][$line]['slave'] ){ $data['interfaces'][] = $line; }
}
sort($data['interfaces']);

$data['route'] = [];
exec('route -n | tail -n +3 | tr -s " " | grep -v "0.0.0.0"', $outputRoute, $rci);
foreach( $outputRoute as $route){
	$routeArr = explode(" ",$route);
	if(count($routeArr)==8){
		$mask = $routeArr[2];
		if( $mask=="255.255.255.255" ){ $mask = ""; }
		$data['route'][] = (object)[ 'destination' => $routeArr[0], 'gateway' => $routeArr[1], 'mask' => $mask, 'if' => $routeArr[7] ];
	}
}

$data['hostname'] = gethostname();


function createNetmaskAddr ($bitcount) {
	$netmask = str_split (str_pad (str_pad ('', $bitcount, '1'), 32, '0'), 8);
	foreach ($netmask as &$element){ $element = bindec ($element); }
	return join ('.', $netmask);
}


//var_dump($data);



// render view

if(hasRequest('createBondingForm') || (hasRequest('createBonding') && $createBondingError)){
	$data['bonding']['name'] = getRequest('bond','');
	$configView = new CView('elisa.network.edit', $data);
}else{
	$configView = new CView('elisa.network', $data);
}
$configView->render();
$configView->show();




require_once dirname(__FILE__).'/include/page_footer.php';
