<?php
/*
** Zabbix
** Copyright (C) 2001-2015 Zabbix SIA
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/



define('TMP_DIRECTORY','/tmp');
define('ELISA_SWUPDATE_SCRIPT','sudo /usr/share/elisa/bin/elisa-swupdate.sh');
define('ELISA_SWUPDATEREMOVE_SCRIPT','sudo /usr/share/elisa/bin/elisa-swupdateRemove.sh');
define('ELISA_GETUPDATE_SCRIPT','sudo /usr/share/elisa/bin/elisa-getUpdates.sh');
define('ELISA_PROXYUPDATE_SCRIPT','sudo /usr/share/elisa/bin/elisa-setHttpProxy.sh');
define('ELISA_VERSION_FILE','/etc/elisa-release');
define('ELISA_CONF',	'/usr/share/elisa/conf/elisa.conf');
define('ELISA_CONF_GUI','/usr/share/elisa/conf/elisa.gui.conf');
define('ELISA_AVAILABLE_PATCHES','/usr/share/elisa/conf/available_patches.txt');


require_once dirname(__FILE__).'/include/config.inc.php';
require_once dirname(__FILE__).'/include/js.inc.php';


$page['title'] = _('ELISA Software Update');
$page['file'] = 'elisa_swupdate.php';
$page['hist_arg'] = array();

require_once dirname(__FILE__).'/include/page_header.php';

$themes = array_keys(Z::getThemes());
$themes[] = THEME_DEFAULT;

// VAR	TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
$fields = array(
	'backurl' => [T_ZBX_STR, O_OPT, null, null, null],
	'update' => [T_ZBX_STR, O_OPT, P_SYS|P_ACT, null, null],
	'cancel' => [T_ZBX_STR, O_OPT, P_SYS, null, null],
	'action' =>	[T_ZBX_STR, O_OPT, P_SYS,
									IN('"update1","update2","update3","updateproxy"'),
									null
								],
	'http_proxy' => [T_ZBX_STR, O_OPT, P_SYS, null, null],
	'downgrade' => [T_ZBX_STR, O_OPT, P_SYS, null, null],
);
check_fields($fields);

	
/*
 * Actions
 */
$data = [];	

$result = true;

if (hasRequest('update')) {
	if(sizeof($_FILES)>0){
		
		if(isset($_FILES['patchfile'])){
			$message_ok = '';
			$message_err = '';

			if($_FILES['patchfile']['error']==0){
				$patchfile = TMP_DIRECTORY."/".$_FILES['patchfile']['name'];
				if (move_uploaded_file($_FILES['patchfile']['tmp_name'],$patchfile)) {
					if(file_exists($patchfile)){
						exec(ELISA_SWUPDATE_SCRIPT.' "'.$patchfile.'"', $patchStatus, $rc);
						$result = true;	
						$message_ok = _('Patch file uploaded and applied');
						$data['patchfile'] = $_FILES['patchfile']['name'];	
						$data['rc'] = $rc;
						$data['output'] = $patchStatus;
						add_audit_details(AUDIT_ACTION_ADD, 99, 0, $_FILES['patchfile']['name'], 'patch-install');
					}else{
						$message_err = _('Error occured during file upload1');
						$result = false;												
					}
				} else {
					//$message_err = _('Při nahrávání souborů došlo k chybě');
					$message_err = _('Error occured during file upload2');
					$result = false;
				};						
			}else{
				$result = false;
				//$message_err = _('Při nahrávání souborů došlo k chybě');
				$message_err = _('Error occured during files upload');
			};
			show_messages($result, $message_ok, $message_err);
		};
		
	}	
}else if (hasRequest('action')){
	if(getRequest('action') == 'update1') {
		exec(ELISA_GETUPDATE_SCRIPT.' -f1 &', $output, $rc);
		show_messages(true, _('Update was finished.'), '');
		add_audit_details(AUDIT_ACTION_ADD, 99, 0, 'OS security packages', 'patch-install');
	}else if (getRequest('action') == 'update2') {
		exec(ELISA_GETUPDATE_SCRIPT.' -f2 &', $output, $rc);
		show_messages(true, _('Update was finished.'), '');
		add_audit_details(AUDIT_ACTION_ADD, 99, 0, 'OS all packages', 'patch-install');
	}else if (getRequest('action') == 'update3') {
		exec(ELISA_GETUPDATE_SCRIPT.' -f3 &', $output, $rc);
		show_messages(true, _('Update was finished.'), '');
		add_audit_details(AUDIT_ACTION_ADD, 99, 0, 'ELISA application', 'patch-install');
	}else if (getRequest('action') == 'updateproxy') {
		$proxyip=-1;
		$proxyport=-1;

		if(getRequest('http_proxy')==""){
			$proxyip="";
			$proxyport="";
		}else{
			preg_match('/^http:\/\/([\d\.]+):(\d+)/', getRequest('http_proxy'), $matches);
			if(count($matches)==3){
				$proxyip=$matches[1];
				$proxyport=$matches[2];
			}else{
				preg_match('/^([\d\.]+):(\d+)/', getRequest('http_proxy'), $matches);
				if(count($matches)==3){
					$proxyip=$matches[1];
					$proxyport=$matches[2];
				}
			}			
		}

		if($proxyip!=-1){
			exec(ELISA_PROXYUPDATE_SCRIPT." \"$proxyip\" \"$proxyport\"", $output, $rc);
			show_messages(true, _('Update was finished.'), '');
			add_audit_details(AUDIT_ACTION_UPDATE, 99, 0, 'ELISA application', 'set http_proxy='.getRequest('http_proxy'));
		}else{
			show_messages(false, '', _('Update failed. Set http_proxy in format \'http://ip:port\''));
		}
	}
}
else if(hasRequest('downgrade')) {
	$versionRemove = ltrim(getRequest('downgrade'),'1_');
	//print ELISA_SWUPDATEREMOVE_SCRIPT." \"$versionRemove\"";
	exec(ELISA_SWUPDATEREMOVE_SCRIPT." \"$versionRemove\"", $output, $rc);
	show_messages(true, _('Downgrade process was finished. Reload page please.'), '');
	header('Location: /zabbix/elisa_swupdate.php');
	die();
}
	


/*
 * Display
 */

	/*
	$serviceStatusFull = shell_exec(HTTPD_STATUS);
	foreach(preg_split("/((\r?\n)|(\r\n?))/", $serviceStatusFull) as $line){
		if(preg_match("/^\s*Active/",$line)) { $serviceStatus = $line; }
	} 
	
	$currentCrt = shell_exec(CRT_CURRENT);
	*/

$UPDATE_OS_SECURITY = shell_exec('grep -i UPDATE_OS_SECURITY= '.ELISA_CONF_GUI.' | cut -d= -f2 | cut -d# -f1');
$UPDATE_OS_ALL = shell_exec('grep -i UPDATE_OS_ALL= '.ELISA_CONF_GUI.' | cut -d= -f2 | cut -d# -f1');
$UPDATE_ELISA = shell_exec('grep -i UPDATE_ELISA= '.ELISA_CONF_GUI.' | cut -d= -f2 | cut -d# -f1');
$UPDATE_ELISA_LOGUPLOAD = shell_exec('grep -i UPDATE_ELISA_LOGUPLOAD= '.ELISA_CONF_GUI.' | cut -d= -f2 | cut -d# -f1');
$UNINSTALL_PATH = shell_exec('grep -i UNINSTALL_PATH= '.ELISA_CONF.' | cut -d= -f2 | cut -d# -f1');
$UNINSTALL_PATH = trim($UNINSTALL_PATH);
$HTTPPROXY = shell_exec('grep -i -e "^\s*proxy" /etc/yum.conf | cut -d= -f2 ');

$data['elisa_version']=file_get_contents(ELISA_VERSION_FILE);	
$data['backurl']='elisa_swupdate.php'; 
$data['configValues']['UPDATE_OS_SECURITY'] = trim($UPDATE_OS_SECURITY);
$data['configValues']['UPDATE_OS_ALL'] = trim($UPDATE_OS_ALL);
$data['configValues']['UPDATE_ELISA'] = trim($UPDATE_ELISA);
$data['configValues']['UPDATE_ELISA_LOGUPLOAD'] = trim($UPDATE_ELISA_LOGUPLOAD);
$data['configValues']['HTTPPROXY'] = trim($HTTPPROXY);
$data['configValues']['ELISA_AVAILABLE_PATCHES'] = ELISA_AVAILABLE_PATCHES;
$data['uninstall'] = false;
$data['prevversion'] = false;
//$data['currentCrt']=$currentCrt; 

$uninstallVersion = substr($data['elisa_version'],6,4)."0";
if( file_exists ( "$UNINSTALL_PATH/$uninstallVersion" ) && file_exists ( "$UNINSTALL_PATH/$uninstallVersion/previousversion.txt" ) ){ 
	$data['uninstall'] = $uninstallVersion; 
	$data['prevversion'] = file_get_contents("$UNINSTALL_PATH/$uninstallVersion/previousversion.txt");
}




// render view
$swupdateView = new CView('elisa.swupdate', $data);
$swupdateView->render();
$swupdateView->show();




require_once dirname(__FILE__).'/include/page_footer.php';
