<?php
/*
** Zabbix
** Copyright (C) 2001-2015 Zabbix SIA
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/




$indicesWidget = (new CWidget())->setTitle(_('ELISA DB Indices'));

/* DIV s obsahem tabu WEB */

$indicesStorageTable = (new CTableInfo())->addStyle('width:0;');
$indicesStorageTable->setHeader(array(_('Storage'),_('DataSize'),_('MountPoint'),_('Total'),_('Used'),_('Free'),_('Used %')));
foreach ($this->data['storage'] as $name => $storage) {
	$indicesStorageTable->addRow(array($name,$storage['dirsize'],$storage['mount'],$storage['total'],$storage['used'],$storage['free'],$storage['usedperc']));
}
$indicesWidget->addItem($indicesStorageTable);
$indicesWidget->addItem((new CTag('br')));


// create form
$indicesForm = (new CForm())->setName('indicesForm');

// create user group table
$indicesTable = new CTableInfo(_('No DB indices found.'));
$indicesTable->setHeader(array(
	(new CColHeader(
			(new CCheckBox('all_indices'))->onClick("checkAll('".$indicesForm->getName()."','all_indices','indicesid');")
		))->addClass(ZBX_STYLE_CELL_WIDTH),
	make_sorting_header(_('Name'), 'name', $this->data['sort'], $this->data['sortorder']),
	make_sorting_header(_('Creation Date'), 'creationDate', $this->data['sort'], $this->data['sortorder']),
	_('Size'),
	_('Log Events'),
	make_sorting_header(_('Status'), 'status', $this->data['sort'], $this->data['sortorder']),
	_('Action'),
	make_sorting_header(_('Retention Mode'), 'retention', $this->data['sort'], $this->data['sortorder']),
	_('Integrity Check')
));

foreach ($this->data['indice'] as $name => $indice) {

	$creationDate = $indice['creationDate']/1000;
	if($creationDate>0){
		$creationDateTxt = date('d.m.Y H:i:s',$creationDate);
	}else{
		$creationDateTxt = '';
	}
	
	
	if($indice['status'] == 'open'){$status = (new CSpan(_('active')))->addClass(ZBX_STYLE_GREEN);}
	else if($indice['status'] == 'close'){$status = (new CSpan(_('closed')))->addClass(ZBX_STYLE_ORANGE);}
	else if($indice['status'] == 'archive'){$status = (new CSpan(_('archived')))->addClass(ZBX_STYLE_GREY);}
	else {$status = $indice['status'];}

	
	$size = '';
	$docs = '';
	if($indice['status'] == "open"){
		if(array_key_exists('size_in_bytes',$indice)){
			$sizeOpt = array(
				'value' => $indice['size_in_bytes'],
				'units' => 'B'
			);
		}else{
			$sizeOpt = array(
				'value' => 0,
				'units' => 'B'
			);
		}
		$size = convert_units($sizeOpt);
		if(array_key_exists('docs_count',$indice)){
			$docs = number_format($indice['docs_count'],0,',',' ');
		}else{
			$docs = number_format(0,0,',',' ');
		}
	}else if($indice['status'] == "archive" || $indice['status'] == "close" ){
		if(array_key_exists('size_in_bytes',$indice) && !is_null($indice['size_in_bytes'])){
			$sizeOpt = array(
				'value' => $indice['size_in_bytes'],
				'units' => 'B'
			);
			$size = convert_units($sizeOpt);
		}else{
			$size = '';
		}		
	}

	$currentdatetime = new DateTime();
	$currenttimestamp = $currentdatetime->getTimestamp();	
	
	$action = array();
	if(($currenttimestamp-$creationDate)<86400 && $indice['status'] == "open" ){ 
		// zivy index neni mozne zavrit/archivovat
	}else{
		if($indice['status'] == 'open'){
			$action[] = (new CLink(_('close'),'elisa_indices.php?action=indices.massclose&indicesid='.$name))->addSID();		$action[] = new CSpan('&nbsp;&nbsp;');
			$action[] = (new CLink(_('archive'),'elisa_indices.php?action=indices.massarchive&indicesid='.$name))->addSID();	$action[] = new CSpan('&nbsp;&nbsp;');
			if( !$data['DISABLE_INDICE_DELETE'] ){ $action[] = (new CLink('delete','elisa_indices.php?action=indices.massdelete&indicesid='.$name))->addConfirmation(_('Delete selected indices? This action can not be undone.'))->addSID(); }
		}
		if($indice['status'] == 'close'){
			$action[] = (new CLink(_('open'),'elisa_indices.php?action=indices.massopen&indicesid='.$name))->addSID();			$action[] = new CSpan('&nbsp;&nbsp;');
			$action[] = (new CLink(_('archive'),'elisa_indices.php?action=indices.massarchive&indicesid='.$name))->addSID();	$action[] = new CSpan('&nbsp;&nbsp;');
			if( !$data['DISABLE_INDICE_DELETE'] ){ $action[] = (new CLink('delete','elisa_indices.php?action=indices.massdelete&indicesid='.$name))->addConfirmation(_('Delete selected indices? This action can not be undone.'))->addSID();	}
		}	
		if($indice['status'] == 'archive'){
			$action[] = (new CLink(_('restore'),'elisa_indices.php?action=indices.massrestore&indicesid='.$name))->addSID();	$action[] = new CSpan('&nbsp;&nbsp;');
			if( !$data['DISABLE_INDICE_DELETE'] ){ $action[] = (new CLink('delete','elisa_indices.php?action=indices.massdelete&indicesid='.$name))->addConfirmation(_('Delete selected indices? This action can not be undone.'))->addSID();	}
		}		
	}
	
	$checkbox = new CCheckBox('indicesid['.$name.']', $name);
	if(($currenttimestamp-$creationDate)<86400 && $indice['status'] == "open" ){$checkbox = '';}
	if($indice['status'] != "open" && $indice['status'] != "close" && $indice['status'] != "archive"){$checkbox = '';}
	
	$retention = '';
	if($indice['retention'] == "auto"){$retention = (new CLink(_('automatic'),'elisa_indices.php?action=indices.retentionmanual&indicesid='.$name))->addSID()->addClass(ZBX_STYLE_GREEN);}
	else if($indice['retention'] == "manual"){$retention = (new CLink(_('manual'),'elisa_indices.php?action=indices.retentionauto&indicesid='.$name))->addSID()->addClass(ZBX_STYLE_ORANGE);}
	
	$integrityCheck = '';
	if(($currenttimestamp-$creationDate)<86400 && $indice['status'] == "open" ){$integrityCheck = (new CSpan(_('live')))->addClass(ZBX_STYLE_GREY); }
	else if($indice['status'] == "open"){
		if( $indice['realMetaHash'] == $indice['metaHash'] ){
			/*$integrityCheck = (new CButton(null, _('pass')))
				->onClick('javascript: if(Confirm("Proceed with deep integrity check? It can take seconds or minutes depending on indice\'s size.")){PopUp("elisa_indices_integrity.php?fullscreen=1&indice='.$name.'",500,400)};')
				->addClass(ZBX_STYLE_BTN_LINK)
				->addClass(ZBX_STYLE_GREEN);*/
			$integrityCheck = (new CSpan(_('pass')))
				->addClass(ZBX_STYLE_GREEN);			
		}else if( !isset($indice['metaHash']) ){
			/*$integrityCheck = (new CButton(null, _('n/a')))
				->onClick('javascript: if(Confirm("Proceed with deep integrity check? It can take seconds or minutes depending on indice\'s size.")){PopUp("elisa_indices_integrity.php?fullscreen=1&indice='.$name.'",500,400)};')
				->addClass(ZBX_STYLE_BTN_LINK)
				->addClass(ZBX_STYLE_GREY);*/
			$integrityCheck = (new CSpan(_('n/a')))
				->addClass(ZBX_STYLE_GREY);				
		}else{
			/*$integrityCheck = (new CButton(null, _('fail')))
				->onClick('javascript: if(Confirm("Proceed with deep integrity check? It can take seconds or minutes depending on indice\'s size.")){PopUp("elisa_indices_integrity.php?fullscreen=1&indice='.$name.'",500,400)};')
				->addClass(ZBX_STYLE_BTN_LINK)
				->addClass(ZBX_STYLE_ORANGE);*/
			$integrityCheck = (new CSpan(_('fail')))
				->addClass(ZBX_STYLE_ORANGE);
		}
	}
	
	$indicesTable->addRow(array(
		$checkbox,
		new CCol($name, 'wraptext'),
		new CCol($creationDateTxt, 'wraptext'),
		new CCol($size, 'wraptext'),
		new CCol($docs, 'wraptext'),
		new CCol($status, 'wraptext'),
		new CCol($action, 'wraptext'),
		new CCol($retention, 'wraptext'),
		new CCol($integrityCheck, 'wraptext')
	));
}

//zbx_add_post_js('chkbxRange.pageGoName = "indicesid";');
zbx_add_post_js('cookie.prefix = "indicesid";');
// append table to form

$actionList = new CActionButtonList('action', 'indicesid',
	[
		'indices.massopen' => ['name' => _('Open'), 'confirm' => _('Open selected indices?')],
		'indices.massclose' => ['name' => _('Close'), 'confirm' => _('Close selected indices?')],
		'indices.massarchive' => ['name' => _('Archive'),	'confirm' => _('Archive selected indices?')],
		//'indices.massrestore' => ['name' => _('Restore'),	'confirm' => _('Restore selected indices?')],
		'indices.massdelete' => ['name' => _('Delete'),	'confirm' => _('Delete selected indices? This action can not be undone.')],
		'indices.retentionmanual' => ['name' => _('Set MANUAL retention mode'),	'confirm' => _('Set MANUAL retention mode for selected indices?')],
		'indices.retentionauto' => ['name' => _('Set AUTOMATIC retention mode'),	'confirm' => _('Set AUTOMATIC retention mode for selected indices?')],
	],
	'indicesid'
);


if( $data['DISABLE_INDICE_DELETE'] ){
	$actionList = new CActionButtonList('action', 'indicesid',
		[
			'indices.massopen' => ['name' => _('Open'), 'confirm' => _('Open selected indices?')],
			'indices.massclose' => ['name' => _('Close'), 'confirm' => _('Close selected indices?')],
			'indices.massarchive' => ['name' => _('Archive'),	'confirm' => _('Archive selected indices?')],
			//'indices.massrestore' => ['name' => _('Restore'),	'confirm' => _('Restore selected indices?')],
			'indices.retentionmanual' => ['name' => _('Set MANUAL retention mode'),	'confirm' => _('Set MANUAL retention mode for selected indices?')],
			'indices.retentionauto' => ['name' => _('Set AUTOMATIC retention mode'),	'confirm' => _('Set AUTOMATIC retention mode for selected indices?')],
		],
		'indicesid'
	);
}

$indicesForm->addItem([
	$indicesTable, 
	$this->data['paging'],
	$actionList
]);


// append form to widget
$indicesWidget->addItem($indicesForm);

return $indicesWidget;
